@@ -14,6 +14,7 @@ InboxModel::InboxModel (QObject * parent)
     roles[IN_NumberRole]= "number";
     roles[IN_Link]      = "link";
     roles[IN_TimeDetail]= "time_detail";
+    roles[IN_SmsText]   = "smstext";
     setRoleNames(roles);
 }//InboxModel::InboxModel
 
@@ -55,6 +56,9 @@ InboxModel::data (const QModelIndex &index,
         case IN_NumberRole:
             column = 4;
             break;
+        case IN_SmsText:
+            column = 6;
+            break;
         }
 
         // Pick up the data from the base class
@@ -176,6 +180,10 @@ InboxModel::data (const QModelIndex &index,
             GVAccess::beautify_number (strNum);
             var = strNum;
         }
+        else if (6 == column)   // GV_IN_SMSTEXT
+        {
+            // Just return the data as is.
+        }
         else
         {
             var.clear ();
