@@ -51,9 +51,6 @@ ObserverFactory::init ()
     AbstractClientPtr appr = (AbstractClientPtr) myobserver;
     clientRegistrar->registerClient(appr, "QGVStreamObserver");
 
-    QObject::connect (
-            myobserver, SIGNAL (log(const QString &, int)),
-            this      , SIGNAL (log(const QString &, int)));
     QObject::connect (
             myobserver, SIGNAL (status(const QString &, int)),
             this      , SIGNAL (status(const QString &, int)));
